==> tecfy_core_package-1.1.38.tar.gz: lib/views/home/notification_list.dart <==
part of tecfy_core_client_package;

class NotificationsListPage extends StatefulWidget {
  final BuildContext? parentContext;
  final onCLick;
  NotificationsListPage({this.parentContext, this.onCLick});
  @override
  _NotificationsListPageState createState() => _NotificationsListPageState();
}

class _NotificationsListPageState extends State<NotificationsListPage>
    with SingleTickerProviderStateMixin {
  late AnimationController controller;
  late Animation<double> _angleAnimation;
  late Animation<double> _feedAnimation;
  late Animation<double> closeAnimation;

  double width = 350;
  double height = 400;
  late double left;
  late double top;
  bool isArabic = false;

  @override
  void initState() {
    isArabic = LocalConfigService.isArabic;
    NotificationListService.beforeClose = () async {
      await controller.animateBack(0);
    };

    super.initState();

    controller =
        AnimationController(vsync: this, duration: Duration(milliseconds: 600));
    _angleAnimation = Tween<double>(begin: 90, end: 0).animate(CurvedAnimation(
        parent: controller, curve: Curves.elasticOut)); //Curves.elasticOut

    _feedAnimation = Tween<double>(begin: 0.0, end: 1)
        .animate(CurvedAnimation(parent: controller, curve: Curves.easeIn));

    controller.addListener(() {
      setState(() {});
    });

    controller.forward();
  }

  @override
  Widget build(BuildContext context) {
    if (widget.parentContext != null) {
      var renderBox = widget.parentContext!.findRenderObject() as RenderBox;
      var size = renderBox.size;
      var offset = renderBox.localToGlobal(Offset.zero);
      top = offset.dy + size.height - 8;
      left = offset.dx - 11;
    } else {
      top = 0;
      left = 0;
    }

    if (left + width > MediaQuery.of(context).size.width) {
      left = MediaQuery.of(context).size.width - width;
    }

    return Positioned(
      top: top,
      left: left,
      width: width,
      child: Transform.rotate(
        alignment: Alignment.topLeft,
        angle: (_angleAnimation.value * 3.14159 / 180),
        child: Opacity(
          opacity: _feedAnimation.value,
          child: Card(
            margin: EdgeInsets.all(10),
            shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.only(
                    topRight:
                        isArabic ? Radius.circular(25) : Radius.circular(0),
                    topLeft:
                        isArabic ? Radius.circular(0) : Radius.circular(25))),
            color: ThemeService.backgroundSecondColor,
            elevation: 15.0,
            child: Container(
                constraints: BoxConstraints(maxHeight: height),
                child: Column(children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      IconButton(
                          icon: Icon(Icons.close),
                          onPressed: () {
                            NotificationListService.hide();
                          }),
                      TextButton(
                          child: Row(children: [
                            TecfyText('Remove All', style: TextStyle
                              (fontSize: 15)),
                            Icon(Icons.restore_from_trash, size: 20),
                          ]),
                          onPressed: () {
                            NotificationAppService.removeAll();
                            NotificationListService.hide();
                          })
                    ],
                  ),
                  Expanded(child: _getList())
                ])),
          ),
        ),
      ),
    );
  }

  divider() {
    return Padding(
        padding: EdgeInsets.symmetric(vertical: 10),
        child: Container(height: 1, color: Colors.white));
  }

  Widget _getList() {
    return StreamBuilder(
      stream: NotificationAppService.notificationCountStream,
      builder: (context, snap) =>
          NotificationAppService.notificationList.length == 0
              ? Center(child: TecfyText('No Record'))
              : ListView(
                  padding: EdgeInsets.all(10),
                  children: NotificationAppService.notificationList
                      .map<Widget>((n) => _getNotificationWidget(n))
                      .toList()
                    ..add(TextButton(
                        child: TecfyText('load more'),
                        onPressed: () =>
                            NotificationAppService.loadOldNotifications())),
                ),
    );
  }

  Widget _getNotificationWidget(n) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            TecfyText(n.title,
                style: TextStyle(color: n.seen ? Colors.black : Colors.red)),
            TecfyText(n.timeString, style: TextStyle(fontSize: 10)),
          ],
        ),
        TecfyText(n.message),
      ],
    );
  }
}

// class NotificationsListPage extends StatefulWidget {
//   @override
//   _NotificationsListPageState createState() => _NotificationsListPageState();
// }

// class _NotificationsListPageState extends State<NotificationsListPage> {
//   bool running = true;

//   @override
//   void dispose() {
//     running = false;
//     super.dispose();
//   }

//   @override
//   void initState() {
//     init();
//     super.initState();
//   }

//   init() async {
//     // mark all notification as seen after 2 seconds
//     await Future.delayed(Duration(seconds: 2));
//     if (running) {
//       await NotificationAppService.markAsRead();
//     }
//   }

//   @override
//   Widget build(BuildContext context) {
//     return LayoutService.bindWidget(context,
//         mobileWidget: _getMobile(), descktopWidget: _getDesktop());
//   }

//   Widget _getDesktop() {
//     return Align(
//       alignment: Alignment.topLeft,
//       child: Padding(
//         padding: EdgeInsets.only(top: 60, left: 60),
//         child: SizedBox(
//           height: 500,
//           width: 350,
//           child: Material(child: _getList()),
//         ),
//       ),
//     );
//   }

//   Widget _getMobile() {
//     return Center(
//       child: SizedBox(
//         height: 500,
//         width: 350,
//         child: Material(child: _getList()),
//       ),
//     );
//   }

// }

==> tecfy_core_package-1.2.7.tar.gz: lib/views/home/notification_list.dart <==
part of tecfy_core_client_package;

class NotificationsListPage extends StatefulWidget {
  final BuildContext? parentContext;
  final onCLick;
  NotificationsListPage({this.parentContext, this.onCLick});
  @override
  _NotificationsListPageState createState() => _NotificationsListPageState();
}

class _NotificationsListPageState extends State<NotificationsListPage>
    with SingleTickerProviderStateMixin {
  late AnimationController controller;
  late Animation<double> _angleAnimation;
  late Animation<double> _feedAnimation;
  late Animation<double> closeAnimation;

  double width = 350;
  double height = 400;
  late double left;
  late double top;
  bool isArabic = false;

  @override
  void initState() {
    isArabic = LocalConfigService.isArabic;
    NotificationListService.beforeClose = () async {
      await controller.animateBack(0);
    };

    super.initState();

    controller =
        AnimationController(vsync: this, duration: Duration(milliseconds: 600));
    _angleAnimation = Tween<double>(begin: 90, end: 0).animate(CurvedAnimation(
        parent: controller, curve: Curves.elasticOut)); //Curves.elasticOut

    _feedAnimation = Tween<double>(begin: 0.0, end: 1)
        .animate(CurvedAnimation(parent: controller, curve: Curves.easeIn));

    controller.addListener(() {
      setState(() {});
    });

    controller.forward();
  }

  @override
  Widget build(BuildContext context) {
    if (widget.parentContext != null) {
      var renderBox = widget.parentContext!.findRenderObject() as RenderBox;
      var size = renderBox.size;
      var offset = renderBox.localToGlobal(Offset.zero);
      top = offset.dy + size.height - 8;
      left = offset.dx - 11;
    } else {
      top = 0;
      left = 0;
    }

    if (left + width > MediaQuery.of(context).size.width) {
      left = MediaQuery.of(context).size.width - width;
    }

    return Positioned(
      top: top,
      left: left,
      width: width,
      child: Transform.rotate(
        alignment: Alignment.topLeft,
        angle: (_angleAnimation.value * 3.14159 / 180),
        child: Opacity(
          opacity: _feedAnimation.value,
          child: Card(
            margin: EdgeInsets.all(10),
            shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.only(
                    topRight:
                        isArabic ? Radius.circular(25) : Radius.circular(0),
                    topLeft:
                        isArabic ? Radius.circular(0) : Radius.circular(25))),
            color: ThemeService.backgroundSecondColor,
            elevation: 15.0,
            surfaceTintColor: Colors.white,
            shadowColor: Colors.white,
            child: Container(
                constraints: BoxConstraints(maxHeight: height),
                child: Column(children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      IconButton(
                          icon: Icon(Icons.close),
                          onPressed: () {
                            NotificationListService.hide();
                          }),
                      TextButton(
                          child: Row(children: [
                            TecfyText('Remove All',
                                style: TextStyle(fontSize: 15)),
                            Icon(Icons.restore_from_trash, size: 20),
                          ]),
                          onPressed: () {
                            NotificationAppService.removeAll();
                            NotificationListService.hide();
                          })
                    ],
                  ),
                  Expanded(child: _getList())
                ])),
          ),
        ),
      ),
    );
  }

  divider() {
    return Padding(
        padding: EdgeInsets.symmetric(vertical: 10),
        child: Container(height: 1, color: Colors.white));
  }

  Widget _getList() {
    return StreamBuilder(
      stream: NotificationAppService.notificationCountStream,
      builder: (context, snap) =>
          NotificationAppService.notificationList.length == 0
              ? Center(child: TecfyText('No Record'))
              : ListView(
                  padding: EdgeInsets.all(10),
                  children: NotificationAppService.notificationList
                      .map<Widget>((n) => _getNotificationWidget(n))
                      .toList()
                    ..add(TextButton(
                        child: TecfyText('load more'),
                        onPressed: () =>
                            NotificationAppService.loadOldNotifications())),
                ),
    );
  }

  Widget _getNotificationWidget(n) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            TecfyText(n.title,
                style: TextStyle(color: n.seen ? Colors.black : Colors.red)),
            TecfyText(n.timeString, style: TextStyle(fontSize: 10)),
          ],
        ),
        TecfyText(n.message),
      ],
    );
  }
}

// class NotificationsListPage extends StatefulWidget {
//   @override
//   _NotificationsListPageState createState() => _NotificationsListPageState();
// }

// class _NotificationsListPageState extends State<NotificationsListPage> {
//   bool running = true;

//   @override
//   void dispose() {
//     running = false;
//     super.dispose();
//   }

//   @override
//   void initState() {
//     init();
//     super.initState();
//   }

//   init() async {
//     // mark all notification as seen after 2 seconds
//     await Future.delayed(Duration(seconds: 2));
//     if (running) {
//       await NotificationAppService.markAsRead();
//     }
//   }

//   @override
//   Widget build(BuildContext context) {
//     return LayoutService.bindWidget(context,
//         mobileWidget: _getMobile(), descktopWidget: _getDesktop());
//   }

//   Widget _getDesktop() {
//     return Align(
//       alignment: Alignment.topLeft,
//       child: Padding(
//         padding: EdgeInsets.only(top: 60, left: 60),
//         child: SizedBox(
//           height: 500,
//           width: 350,
//           child: Material(child: _getList()),
//         ),
//       ),
//     );
//   }

//   Widget _getMobile() {
//     return Center(
//       child: SizedBox(
//         height: 500,
//         width: 350,
//         child: Material(child: _getList()),
//       ),
//     );
//   }

// }
